==> haskell-wai-logger-2.3.4-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.4
id: wai-logger-2.3.4-KMBk7wqgzFWE45xFzZ6Jgj
key: wai-logger-2.3.4-KMBk7wqgzFWE45xFzZ6Jgj
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
abi: 6a59d7ab2e043900d4799ff69f227b72
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-logger-2.3.4
hs-libraries: HSwai-logger-2.3.4-KMBk7wqgzFWE45xFzZ6Jgj
depends:
    base-4.12.0.0 byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw
    bytestring-0.10.8.2 fast-logger-2.4.15-3GvScLVsrwt2bRGHnUNSQz
    http-types-0.12.3-Ge4lCiHP3W4Hc9xNIKz9xs
    network-2.8.0.0-JWTbamlNgQDGa4CnHHLrSE
    wai-3.2.2-4c2pxdLfag64JAZMTaiyBj
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.3.4-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.4
id: wai-logger-2.3.4-FcforDS4NXADMKwCUUIEJP
key: wai-logger-2.3.4-FcforDS4NXADMKwCUUIEJP
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
abi: a92ab7eb8763864db1f719ae03fc0762
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-logger-2.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-logger-2.3.4
hs-libraries: HSwai-logger-2.3.4-FcforDS4NXADMKwCUUIEJP
depends:
    base-4.12.0.0 byteorder-1.0.4-IVStE0plZAH4UpHo5zwztw
    bytestring-0.10.8.2 fast-logger-2.4.15-AE46mNxj6Pu3lnzFsNEfpc
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    wai-3.2.2-GlQJpLVznLECwkQpTtQzT9
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
